var classplplot =
[
    [ "pl_setcontlabelformat", "interfaceplplot_1_1pl__setcontlabelformat.html", "interfaceplplot_1_1pl__setcontlabelformat" ],
    [ "pladv", "interfaceplplot_1_1pladv.html", "interfaceplplot_1_1pladv" ],
    [ "plbop", "interfaceplplot_1_1plbop.html", "interfaceplplot_1_1plbop" ],
    [ "plclear", "interfaceplplot_1_1plclear.html", "interfaceplplot_1_1plclear" ],
    [ "plcol0", "interfaceplplot_1_1plcol0.html", "interfaceplplot_1_1plcol0" ],
    [ "plcpstrm", "interfaceplplot_1_1plcpstrm.html", "interfaceplplot_1_1plcpstrm" ],
    [ "plend", "interfaceplplot_1_1plend.html", "interfaceplplot_1_1plend" ],
    [ "plend1", "interfaceplplot_1_1plend1.html", "interfaceplplot_1_1plend1" ],
    [ "pleop", "interfaceplplot_1_1pleop.html", "interfaceplplot_1_1pleop" ],
    [ "plfamadv", "interfaceplplot_1_1plfamadv.html", "interfaceplplot_1_1plfamadv" ],
    [ "plflush", "interfaceplplot_1_1plflush.html", "interfaceplplot_1_1plflush" ],
    [ "plfont", "interfaceplplot_1_1plfont.html", "interfaceplplot_1_1plfont" ],
    [ "plfontld", "interfaceplplot_1_1plfontld.html", "interfaceplplot_1_1plfontld" ],
    [ "plgcol0", "interfaceplplot_1_1plgcol0.html", "interfaceplplot_1_1plgcol0" ],
    [ "plgcolbg", "interfaceplplot_1_1plgcolbg.html", "interfaceplplot_1_1plgcolbg" ],
    [ "plgcompression", "interfaceplplot_1_1plgcompression.html", "interfaceplplot_1_1plgcompression" ],
    [ "plgdev", "interfaceplplot_1_1plgdev.html", "interfaceplplot_1_1plgdev" ],
    [ "plgdrawmode", "interfaceplplot_1_1plgdrawmode.html", "interfaceplplot_1_1plgdrawmode" ],
    [ "plgfam", "interfaceplplot_1_1plgfam.html", "interfaceplplot_1_1plgfam" ],
    [ "plgfci", "interfaceplplot_1_1plgfci.html", "interfaceplplot_1_1plgfci" ],
    [ "plgfnam", "interfaceplplot_1_1plgfnam.html", "interfaceplplot_1_1plgfnam" ],
    [ "plgfont", "interfaceplplot_1_1plgfont.html", "interfaceplplot_1_1plgfont" ],
    [ "plglevel", "interfaceplplot_1_1plglevel.html", "interfaceplplot_1_1plglevel" ],
    [ "plgra", "interfaceplplot_1_1plgra.html", "interfaceplplot_1_1plgra" ],
    [ "plgstrm", "interfaceplplot_1_1plgstrm.html", "interfaceplplot_1_1plgstrm" ],
    [ "plgver", "interfaceplplot_1_1plgver.html", "interfaceplplot_1_1plgver" ],
    [ "plgxax", "interfaceplplot_1_1plgxax.html", "interfaceplplot_1_1plgxax" ],
    [ "plgyax", "interfaceplplot_1_1plgyax.html", "interfaceplplot_1_1plgyax" ],
    [ "plgzax", "interfaceplplot_1_1plgzax.html", "interfaceplplot_1_1plgzax" ],
    [ "plinit", "interfaceplplot_1_1plinit.html", "interfaceplplot_1_1plinit" ],
    [ "pllab", "interfaceplplot_1_1pllab.html", "interfaceplplot_1_1pllab" ],
    [ "pllsty", "interfaceplplot_1_1pllsty.html", "interfaceplplot_1_1pllsty" ],
    [ "plmkstrm", "interfaceplplot_1_1plmkstrm.html", "interfaceplplot_1_1plmkstrm" ],
    [ "plparseopts", "interfaceplplot_1_1plparseopts.html", "interfaceplplot_1_1plparseopts" ],
    [ "plpat", "interfaceplplot_1_1plpat.html", "interfaceplplot_1_1plpat" ],
    [ "plprec", "interfaceplplot_1_1plprec.html", "interfaceplplot_1_1plprec" ],
    [ "plpsty", "interfaceplplot_1_1plpsty.html", "interfaceplplot_1_1plpsty" ],
    [ "plreplot", "interfaceplplot_1_1plreplot.html", "interfaceplplot_1_1plreplot" ],
    [ "plscmap0", "interfaceplplot_1_1plscmap0.html", "interfaceplplot_1_1plscmap0" ],
    [ "plscmap0n", "interfaceplplot_1_1plscmap0n.html", "interfaceplplot_1_1plscmap0n" ],
    [ "plscmap1", "interfaceplplot_1_1plscmap1.html", "interfaceplplot_1_1plscmap1" ],
    [ "plscmap1n", "interfaceplplot_1_1plscmap1n.html", "interfaceplplot_1_1plscmap1n" ],
    [ "plscol0", "interfaceplplot_1_1plscol0.html", "interfaceplplot_1_1plscol0" ],
    [ "plscolbg", "interfaceplplot_1_1plscolbg.html", "interfaceplplot_1_1plscolbg" ],
    [ "plscolor", "interfaceplplot_1_1plscolor.html", "interfaceplplot_1_1plscolor" ],
    [ "plscompression", "interfaceplplot_1_1plscompression.html", "interfaceplplot_1_1plscompression" ],
    [ "plsdev", "interfaceplplot_1_1plsdev.html", "interfaceplplot_1_1plsdev" ],
    [ "plsdrawmode", "interfaceplplot_1_1plsdrawmode.html", "interfaceplplot_1_1plsdrawmode" ],
    [ "plseed", "interfaceplplot_1_1plseed.html", "interfaceplplot_1_1plseed" ],
    [ "plsesc", "interfaceplplot_1_1plsesc.html", "interfaceplplot_1_1plsesc" ],
    [ "plsetopt", "interfaceplplot_1_1plsetopt.html", "interfaceplplot_1_1plsetopt" ],
    [ "plsfam", "interfaceplplot_1_1plsfam.html", "interfaceplplot_1_1plsfam" ],
    [ "plsfci", "interfaceplplot_1_1plsfci.html", "interfaceplplot_1_1plsfci" ],
    [ "plsfnam", "interfaceplplot_1_1plsfnam.html", "interfaceplplot_1_1plsfnam" ],
    [ "plsfont", "interfaceplplot_1_1plsfont.html", "interfaceplplot_1_1plsfont" ],
    [ "plsmem", "interfaceplplot_1_1plsmem.html", "interfaceplplot_1_1plsmem" ],
    [ "plsmema", "interfaceplplot_1_1plsmema.html", "interfaceplplot_1_1plsmema" ],
    [ "plsori", "interfaceplplot_1_1plsori.html", "interfaceplplot_1_1plsori" ],
    [ "plspal0", "interfaceplplot_1_1plspal0.html", "interfaceplplot_1_1plspal0" ],
    [ "plspal1", "interfaceplplot_1_1plspal1.html", "interfaceplplot_1_1plspal1" ],
    [ "plspause", "interfaceplplot_1_1plspause.html", "interfaceplplot_1_1plspause" ],
    [ "plsstrm", "interfaceplplot_1_1plsstrm.html", "interfaceplplot_1_1plsstrm" ],
    [ "plssub", "interfaceplplot_1_1plssub.html", "interfaceplplot_1_1plssub" ],
    [ "plstar", "interfaceplplot_1_1plstar.html", "interfaceplplot_1_1plstar" ],
    [ "plstart", "interfaceplplot_1_1plstart.html", "interfaceplplot_1_1plstart" ],
    [ "plstripd", "interfaceplplot_1_1plstripd.html", "interfaceplplot_1_1plstripd" ],
    [ "plstyl", "interfaceplplot_1_1plstyl.html", "interfaceplplot_1_1plstyl" ],
    [ "plsvect", "interfaceplplot_1_1plsvect.html", "interfaceplplot_1_1plsvect" ],
    [ "plsxax", "interfaceplplot_1_1plsxax.html", "interfaceplplot_1_1plsxax" ],
    [ "plsyax", "interfaceplplot_1_1plsyax.html", "interfaceplplot_1_1plsyax" ],
    [ "plszax", "interfaceplplot_1_1plszax.html", "interfaceplplot_1_1plszax" ],
    [ "pltext", "interfaceplplot_1_1pltext.html", "interfaceplplot_1_1pltext" ],
    [ "pltimefmt", "interfaceplplot_1_1pltimefmt.html", "interfaceplplot_1_1pltimefmt" ],
    [ "plvsta", "interfaceplplot_1_1plvsta.html", "interfaceplplot_1_1plvsta" ],
    [ "plxormod", "interfaceplplot_1_1plxormod.html", "interfaceplplot_1_1plxormod" ],
    [ "pl_setcontlabelformat_impl", "classplplot.html#ac41618acbbb71d22152d6664ed7ea8f8", null ],
    [ "pladv_impl", "classplplot.html#a5626fb76d37465da38a57c20ab0a0a7b", null ],
    [ "plbop_impl", "classplplot.html#acf34437c2142d1cc040fdbd6adab86f1", null ],
    [ "plclear_impl", "classplplot.html#a115044b2ac5ae152f3f114db61d714c7", null ],
    [ "plcol0_impl", "classplplot.html#ad2067a9f4dce8ac54994d599ec758c54", null ],
    [ "plcpstrm_impl", "classplplot.html#a921622c2d988b9c833f1a52708c1f015", null ],
    [ "plend1_impl", "classplplot.html#a63166bebdbf632724bd6f43b1139e776", null ],
    [ "plend_impl", "classplplot.html#a5e1e92483394ad7558c605e7b94eb356", null ],
    [ "pleop_impl", "classplplot.html#ae89f3a4f182e0e481074eead72e15ab3", null ],
    [ "plfamadv_impl", "classplplot.html#ad4a2b85be5f1e80765f70da069dc403f", null ],
    [ "plflush_impl", "classplplot.html#a61cc00600844d98180281c641358f5e5", null ],
    [ "plfont_impl", "classplplot.html#a2a7c9b45bdb8faeb3605060e83bc4411", null ],
    [ "plfontld_impl", "classplplot.html#ae3994eef5f5aa2f3b34f5e47b4a5ead4", null ],
    [ "plgcol0_impl", "classplplot.html#ab02353684d43e3ffc72308ae0e62eb22", null ],
    [ "plgcolbg_impl", "classplplot.html#a54864386f276494f28386bd5c64b3a06", null ],
    [ "plgcompression_impl", "classplplot.html#af7b37c19ff64c92200ebad46ce2adc7f", null ],
    [ "plgdev_impl", "classplplot.html#a7d7587223ace15e979c085fb2a91a039", null ],
    [ "plgdrawmode_impl", "classplplot.html#aa9d0322efdd93095bccd769640103bae", null ],
    [ "plgfam_impl", "classplplot.html#a1ae7159a0bde310740d4a8a753b7c425", null ],
    [ "plgfci_impl", "classplplot.html#adbd2ca3fd56fc0f9f785b5c83a3bd201", null ],
    [ "plgfnam_impl", "classplplot.html#a7a236472d225006caf8cde33a6e1f6b7", null ],
    [ "plgfont_impl", "classplplot.html#a306e53a422d275981911acc402e5ca35", null ],
    [ "plglevel_impl", "classplplot.html#a5cbadc93aa90ab42404dc62c0263694c", null ],
    [ "plgra_impl", "classplplot.html#a54575f8d30fdc1259ad0d25f6ec1e38e", null ],
    [ "plgstrm_impl", "classplplot.html#a52da94cf3588e84ab46ea0a3d18ae506", null ],
    [ "plgver_impl", "classplplot.html#a49bab9579649caf970dbb6bd28205d9b", null ],
    [ "plgxax_impl", "classplplot.html#a08ab61e48b23b314aee3d0e2aab052b7", null ],
    [ "plgyax_impl", "classplplot.html#a7062ed1a9200c24101abce45a09fd72b", null ],
    [ "plgzax_impl", "classplplot.html#aac0315657170bdd7a8954759c218be8a", null ],
    [ "plinit_impl", "classplplot.html#a59f4e6cd4a3602b9df90429b48c50a60", null ],
    [ "pllab_impl", "classplplot.html#a601a7c14557336d7c45b1fcff7e558c9", null ],
    [ "pllsty_impl", "classplplot.html#aba027f7c0ddfbc8c39154cca7c47ede5", null ],
    [ "plmkstrm_impl", "classplplot.html#a007f51cbfec504e13383305a8f0f7e5c", null ],
    [ "plparseopts_impl", "classplplot.html#a767023057cd5adad7661ea9b2d135d25", null ],
    [ "plpat_impl", "classplplot.html#a7e60cf8a8395dd3a3b184da92978fa52", null ],
    [ "plprec_impl", "classplplot.html#a34dba1bd6e83d35b2ddc70a2fcb58c6f", null ],
    [ "plpsty_impl", "classplplot.html#a5e9df072c358261f8133d7302d1e02d2", null ],
    [ "plreplot_impl", "classplplot.html#a9434f40473c5c1fb541a77bc41a286fb", null ],
    [ "plscmap0_impl", "classplplot.html#a8d8d661d818cf4b57c82d84a789f88ac", null ],
    [ "plscmap0n_impl", "classplplot.html#a5b1451b7264b90bc4d2d31cd6d50d2a0", null ],
    [ "plscmap1_impl", "classplplot.html#aab374afd917a62aaa5b771e6d93b7ab5", null ],
    [ "plscmap1n_impl", "classplplot.html#ac3c7ce7a87041a0d25bd5118f3e54bdc", null ],
    [ "plscol0_impl", "classplplot.html#a7037fdfc9842c5eedd62fbc94d565b87", null ],
    [ "plscolbg_impl", "classplplot.html#a70f3c1ac3250c861cca7f6c9db9f2ad3", null ],
    [ "plscolor_impl", "classplplot.html#a4e8ef93cbc4b1803b89b33a0be4149f0", null ],
    [ "plscompression_impl", "classplplot.html#af37209f7f15669f222b0fbca705f5cde", null ],
    [ "plsdev_impl", "classplplot.html#a272485216ae6961b486af03cfb15e0db", null ],
    [ "plsdrawmode_impl", "classplplot.html#aa758a41cbab9ad3f26e659dd79a01692", null ],
    [ "plseed_impl", "classplplot.html#a61126eaaf6eef4bd979f961786bd957f", null ],
    [ "plsesc_impl", "classplplot.html#aa5475b3fad5c942e1f3124719c9326b5", null ],
    [ "plsetopt_impl", "classplplot.html#ae52661db4f45e6f2b38b99216474955f", null ],
    [ "plsfam_impl", "classplplot.html#a08a81cb9d3806819f313db97d72c21fe", null ],
    [ "plsfci_impl", "classplplot.html#a6908a2cf04f7187b0ac12088a7409669", null ],
    [ "plsfnam_impl", "classplplot.html#a95a5f4be0fcae34ae78aabe0d554a2f6", null ],
    [ "plsfont_impl", "classplplot.html#aebb5c3a17c9d6ed2c5b2446d9c0fa702", null ],
    [ "plsmem_impl", "classplplot.html#adc7808752a9159f1695f697aa2f18dd2", null ],
    [ "plsmema_impl", "classplplot.html#a54f9cc4cbe56a1b587c087e761486f19", null ],
    [ "plsori_impl", "classplplot.html#abf4f5e1a1c361f103d486ee7ff4d2660", null ],
    [ "plspal0_impl", "classplplot.html#a4066219818d7a8cfa57f60581c9a8553", null ],
    [ "plspal1_impl", "classplplot.html#ac02394e9f183f33cfc7ab934805fb9af", null ],
    [ "plspause_impl", "classplplot.html#a1f97486742a0baa17dfd03143233fcb9", null ],
    [ "plsstrm_impl", "classplplot.html#a85d62a0e04b8080b1a64c3806e88b367", null ],
    [ "plssub_impl", "classplplot.html#a440cd4237bb0a2962b734bca83dbc116", null ],
    [ "plstar_impl", "classplplot.html#a4baedfe010f8df623904984a8e4b3b8e", null ],
    [ "plstart_impl", "classplplot.html#a78af68a6ffa0d167ee3fe5dec961bbd8", null ],
    [ "plstripd_impl", "classplplot.html#a78dad702d1ed0b3a197a36b0dff07f64", null ],
    [ "plstyl_impl", "classplplot.html#afecf2a6a27df8b46180bb9ff1011f390", null ],
    [ "plsvect_none", "classplplot.html#a37b98577d4ed055b1cdc69ab9efa2053", null ],
    [ "plsxax_impl", "classplplot.html#aa6805d490e36adfa911d53f8246eca94", null ],
    [ "plsyax_impl", "classplplot.html#a6947089338ce0e313d567668d09ed8ca", null ],
    [ "plszax_impl", "classplplot.html#a514a734c0374a29b9d8977823e766e51", null ],
    [ "pltext_impl", "classplplot.html#a47c66102c440ad8e94c697a6d8aee94f", null ],
    [ "pltimefmt_impl", "classplplot.html#a8810dc14da396d2a584ac2fb431f6254", null ],
    [ "plvsta_impl", "classplplot.html#ab88ae02d5f8053dcd1a5b93872c18cef", null ],
    [ "plxormod_impl", "classplplot.html#a81076e05e1b05629dc39e8e48dc59b85", null ],
    [ "__pad0__", "classplplot.html#a99e3a2f7f971b4759590ff8f417e4d4e", null ],
    [ "Alloc2dGrid", "classplplot.html#ae7e2909e2bcc51a61a0c0259ec330876", null ],
    [ "BASE_CONT", "classplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6", null ],
    [ "c_PLcGrid", "classplplot.html#ae0952584f6d3334a3314373e9de68ab2", null ],
    [ "c_PLcGrid2", "classplplot.html#ac0a3be6d22835e74179254e1635499bc", null ],
    [ "DRAW_LINEX", "classplplot.html#a53c151ff9300048429b05568946f4b58", null ],
    [ "DRAW_LINEXY", "classplplot.html#ab4fc454297b7b4df3c1f73fe9dae4cbe", null ],
    [ "DRAW_LINEY", "classplplot.html#aa566c9a8b5967e071359585fbbe5975e", null ],
    [ "DRAW_SIDES", "classplplot.html#a498074676eb148d19d7465505e44ae2c", null ],
    [ "FACETED", "classplplot.html#a18562f076d6241fcb70174c56cc9d0f2", null ],
    [ "Free2dGrid", "classplplot.html#a284542add18e412b4f9f6b071dc6a9b3", null ],
    [ "GRID_CSA", "classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7", null ],
    [ "GRID_DTLI", "classplplot.html#a69350e251c909eb5d9dc20469b532bcb", null ],
    [ "GRID_NNAIDW", "classplplot.html#a14854e59f92a3552380e29a55d06622f", null ],
    [ "GRID_NNI", "classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48", null ],
    [ "GRID_NNIDW", "classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1", null ],
    [ "GRID_NNLI", "classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5", null ],
    [ "MAG_COLOR", "classplplot.html#ac50f05d8a58f2960cfe2a496d11fcad0", null ],
    [ "maxlen", "classplplot.html#a0771bb612935378464fba135a16618b8", null ],
    [ "MESH", "classplplot.html#a0a7a72416f1a62cbc7d6ed176f0889a0", null ],
    [ "MinMax2dGrid", "classplplot.html#a22297be3066bb6e8e6330143ac0d00e4", null ],
    [ "ONEW2B", "classplplot.html#a682ba4d7edb5b72c8768df356142ebb0", null ],
    [ "ONEW2D", "classplplot.html#a778b78c3e46e3647c5b8ce171f26d437", null ],
    [ "PL_BIN_CENTRED", "classplplot.html#a8b4bb482aa4a3b5d387abd08ee17447d", null ],
    [ "PL_BIN_DEFAULT", "classplplot.html#aee6daf582b74c0c933b4c41785d6b758", null ],
    [ "PL_BIN_NOEMPTY", "classplplot.html#aa8d1c08833503083724c3a0a43439338", null ],
    [ "PL_BIN_NOEXPAND", "classplplot.html#a861aa362a8d7f9831098df18043b7174", null ],
    [ "PL_COLORBAR_BACKGROUND", "classplplot.html#a21c06c6b1e046ab4475a0be61786056a", null ],
    [ "PL_COLORBAR_BOUNDING_BOX", "classplplot.html#a9e3ede3e77dd286ead007636997e9fdf", null ],
    [ "PL_COLORBAR_CAP_HIGH", "classplplot.html#a45c37e1750252906687fa48e8b1b952e", null ],
    [ "PL_COLORBAR_CAP_LOW", "classplplot.html#af8a31f853ad692afcefda3b1403d48a3", null ],
    [ "PL_COLORBAR_CAP_NONE", "classplplot.html#aec6961d048e4e6c44600167ba2eafe6e", null ],
    [ "PL_COLORBAR_GRADIENT", "classplplot.html#a3fbb9171d73f5670d2ebf52797775966", null ],
    [ "PL_COLORBAR_IMAGE", "classplplot.html#a54d83e729244593e941e983a178dcbed", null ],
    [ "PL_COLORBAR_LABEL_BOTTOM", "classplplot.html#afb7c78bd45e9cc20292b47aeba5f3cf6", null ],
    [ "PL_COLORBAR_LABEL_LEFT", "classplplot.html#ab931accd246a77a15f52bdcc128312b1", null ],
    [ "PL_COLORBAR_LABEL_RIGHT", "classplplot.html#a3b408dc01e7d4e6d27e75f45aebb6910", null ],
    [ "PL_COLORBAR_LABEL_TOP", "classplplot.html#a043ad3aaaf5c6e4e8d4098a839c7a860", null ],
    [ "PL_COLORBAR_ORIENT_BOTTOM", "classplplot.html#a45f22534aeca33d204ab1997e301d63b", null ],
    [ "PL_COLORBAR_ORIENT_LEFT", "classplplot.html#a05c866ccb90c8f5e7f9fcba47ca06f97", null ],
    [ "PL_COLORBAR_ORIENT_RIGHT", "classplplot.html#ab95f67a66d9c54530c49db3dc37409db", null ],
    [ "PL_COLORBAR_ORIENT_TOP", "classplplot.html#ada262759b3f6373dcbb2c0a268f26428", null ],
    [ "PL_COLORBAR_SHADE", "classplplot.html#a8913e33754cfef14eff15beb1bf46a5c", null ],
    [ "PL_COLORBAR_SHADE_LABEL", "classplplot.html#ae9c45984e846d89e6311b679ebe5defe", null ],
    [ "pl_end_of_string", "classplplot.html#ac0b4623331c1704fba8ab480d3ed938c", null ],
    [ "PL_FCI_BOLD", "classplplot.html#ad5c19171b3782b2b1c76d3b6dbe4e41c", null ],
    [ "PL_FCI_FAMILY", "classplplot.html#af00dc4a620e90ffd9481790fc7396ce7", null ],
    [ "PL_FCI_HEXDIGIT_MASK", "classplplot.html#a6e2bbc3ec109f773d0b9d6ff6c6c4110", null ],
    [ "PL_FCI_HEXPOWER_IMPOSSIBLE", "classplplot.html#a0830e4784c9210bdc7d1a248c6a92616", null ],
    [ "PL_FCI_HEXPOWER_MASK", "classplplot.html#a25300695cbc578f880a157945cc438b3", null ],
    [ "PL_FCI_IMPOSSIBLE", "classplplot.html#ae67da199d784c8752fdb8ddb7d371778", null ],
    [ "PL_FCI_ITALIC", "classplplot.html#acba7b79270e714987d94961e5053e36f", null ],
    [ "PL_FCI_MARK", "classplplot.html#ad397ee04fd837f53bbd23168bc8938d9", null ],
    [ "PL_FCI_MEDIUM", "classplplot.html#a880960d5564abca4dc5937ea0d8e3521", null ],
    [ "PL_FCI_MONO", "classplplot.html#a16c198fd39b21e38ef459a11089b5740", null ],
    [ "PL_FCI_OBLIQUE", "classplplot.html#acf041a00a5aff414d8ef0338c79d1fde", null ],
    [ "PL_FCI_SANS", "classplplot.html#a16f0c9eaafc7a35c7d61e8f24ab095df", null ],
    [ "PL_FCI_SCRIPT", "classplplot.html#a4d553fa02b87433db091aa46dc601a5f", null ],
    [ "PL_FCI_SERIF", "classplplot.html#a6c3a63d8ab70e8c50d27e226c47dc802", null ],
    [ "PL_FCI_STYLE", "classplplot.html#a210ca726e6dcdc4f56f1e3f5d9275711", null ],
    [ "PL_FCI_SYMBOL", "classplplot.html#a5ae9d36b98641eaad957204227fd44cb", null ],
    [ "PL_FCI_UPRIGHT", "classplplot.html#a5232bd6cf21866b29048554dcdc40335", null ],
    [ "PL_FCI_WEIGHT", "classplplot.html#afe1b47ac660b3c4b68ce68875297e521", null ],
    [ "PL_HIST_DEFAULT", "classplplot.html#ae664ef65530eea52bb33d23e013436cf", null ],
    [ "PL_HIST_IGNORE_OUTLIERS", "classplplot.html#a7303f4afaa30ab050b98415ccc078422", null ],
    [ "PL_HIST_NOEMPTY", "classplplot.html#a6f5b48bed581eda8e674fde4eb0661d9", null ],
    [ "PL_HIST_NOEXPAND", "classplplot.html#a05f2f5a4310eb2bb51bb24932eac95fc", null ],
    [ "PL_HIST_NOSCALING", "classplplot.html#ab094c5af4e566f29ffd5705d535c5e1f", null ],
    [ "PL_LEGEND_BACKGROUND", "classplplot.html#a3d75fe4de9052aacff7f5091025c04ed", null ],
    [ "PL_LEGEND_BOUNDING_BOX", "classplplot.html#a3af5ae5127d1f51b3cdc65c01fc5e882", null ],
    [ "PL_LEGEND_COLOR_BOX", "classplplot.html#a0a9f25fdc8fa51ec4582463fbdcc8872", null ],
    [ "PL_LEGEND_LINE", "classplplot.html#a5a6b51823871ef7424186349e3761898", null ],
    [ "PL_LEGEND_NONE", "classplplot.html#afc67cad19f2ce126af591cfbea9c95b8", null ],
    [ "PL_LEGEND_ROW_MAJOR", "classplplot.html#a8e7c02f62e023c437c39ca721db3da39", null ],
    [ "PL_LEGEND_SYMBOL", "classplplot.html#a02e22aa6be1044324bbe070bef0d8654", null ],
    [ "PL_LEGEND_TEXT_LEFT", "classplplot.html#a698d5046d976c3901ed82da8c7c648e3", null ],
    [ "PL_MAXKEY", "classplplot.html#a519a3647d4a9164a6c3448d75e467ee0", null ],
    [ "PL_MAXWINDOWS", "classplplot.html#aaf6716db6f94369f85e4a3133b3c2f3f", null ],
    [ "PL_NOTSET", "classplplot.html#aa7eaae1c9ab27faf4ca609746c2d5f01", null ],
    [ "PL_OPT_ARG", "classplplot.html#a22de3264860e2ce779ab6d785eacebc0", null ],
    [ "PL_OPT_BOOL", "classplplot.html#a5b5a7d33258290b84d4b577aaab1c09d", null ],
    [ "PL_OPT_DISABLED", "classplplot.html#a4dd508fd67a2a8fa16520f2665e4319f", null ],
    [ "PL_OPT_ENABLED", "classplplot.html#a3f2a30bd2e6f79b41fa25570251d162a", null ],
    [ "PL_OPT_FLOAT", "classplplot.html#a214eb94c19b123881ea133e15b1e58fe", null ],
    [ "PL_OPT_FUNC", "classplplot.html#a5f56a02a4fb93427ab66e0a72b9a9d8e", null ],
    [ "PL_OPT_INT", "classplplot.html#a8980554346127a400d0fb905931a3889", null ],
    [ "PL_OPT_INVISIBLE", "classplplot.html#a6c63bb867085cd87302922ca7d205056", null ],
    [ "PL_OPT_NODELETE", "classplplot.html#a42f883ffb80065fa19774f554b8c1e6f", null ],
    [ "PL_OPT_STRING", "classplplot.html#a44533ceab40f92f02a4fd1cde7afc2d4", null ],
    [ "PL_PARSE_FULL", "classplplot.html#a261101736f21924ec80e254b63258304", null ],
    [ "PL_PARSE_NODASH", "classplplot.html#ab396b3c8123fa19eeb649a175175c032", null ],
    [ "PL_PARSE_NODELETE", "classplplot.html#a9891ed6cce9b02ce103a01bc88f4484d", null ],
    [ "PL_PARSE_NOPROGRAM", "classplplot.html#acb62e30faebb753535ee8c24f9d37b6b", null ],
    [ "PL_PARSE_OVERRIDE", "classplplot.html#af7487079ed393ed63fe54a0f951ead16", null ],
    [ "PL_PARSE_PARTIAL", "classplplot.html#afea2ee06309d8a1592e023fa7052e1ef", null ],
    [ "PL_PARSE_QUIET", "classplplot.html#ab26442732ed6e2042b36b8af25d9a649", null ],
    [ "PL_PARSE_SHOWALL", "classplplot.html#a7f5a7d45f9e7add01640b4e708293667", null ],
    [ "PL_PARSE_SKIP", "classplplot.html#aadfee6aca3a9ce1222524f84b979e5f8", null ],
    [ "PL_POSITION_BOTTOM", "classplplot.html#a1d1c007d4c2142a8641b088cd09a876d", null ],
    [ "PL_POSITION_INSIDE", "classplplot.html#a62c4aae58e473a0a2d932a9f53265260", null ],
    [ "PL_POSITION_LEFT", "classplplot.html#abac10a1448047081f317570f1218fc39", null ],
    [ "PL_POSITION_OUTSIDE", "classplplot.html#a80f6536884b018ed6a6399e242c11832", null ],
    [ "PL_POSITION_RIGHT", "classplplot.html#a6eab4aca6ab601078b3922e67321e405", null ],
    [ "PL_POSITION_SUBPAGE", "classplplot.html#aa5b4c0a51c3a51687f21f57018d162b0", null ],
    [ "PL_POSITION_TOP", "classplplot.html#ad2b8fb43049ae5a9515f6c5de7b2a249", null ],
    [ "PL_POSITION_VIEWPORT", "classplplot.html#afdb08ad07520cbae622ca660e4e39c92", null ],
    [ "pl_setcontlabelformat", "classplplot.html#a4bb455a23067a0a31054fbbd2df9a803", null ],
    [ "pl_setcontlabelparam", "classplplot.html#a67f9326e173007cd7320aa90afc682a4", null ],
    [ "pl_test_flt", "classplplot.html#aa8a085057363aec3c1f87b6201b6dc6e", null ],
    [ "PL_X_AXIS", "classplplot.html#a9c778b860f2871a585009497787919e6", null ],
    [ "PL_Y_AXIS", "classplplot.html#ae2114d3d365951b2982495ea8c5d74bc", null ],
    [ "PL_Z_AXIS", "classplplot.html#a3db3b59a6a597a00ad7d5e3cd8189e6c", null ],
    [ "pladv", "classplplot.html#ad4160f178ade6ce47ddf69113ca8a1d6", null ],
    [ "plarc", "classplplot.html#a3a3d8a53fd056ab44f8318b96dc707f5", null ],
    [ "PLBOOL", "classplplot.html#aed3a1ce8dd8ffdd4cc49a02a91185eca", null ],
    [ "plbop", "classplplot.html#a14a6d89255e518170eec470678a22cbe", null ],
    [ "plbtime", "classplplot.html#a6dce74122c4fedafd5dcd365757f7fdd", null ],
    [ "PLBufferingCB", "classplplot.html#a63efafe2f195046ea5cea3d3ad0177b2", null ],
    [ "plcalc_world", "classplplot.html#a360056f26a247b8ad2b465508184ea89", null ],
    [ "plclear", "classplplot.html#a324f6b1aa925cd0e6ee324005a56e4ad", null ],
    [ "plclr", "classplplot.html#ada9a848fca721868333e62f4f50cb795", null ],
    [ "plcol", "classplplot.html#adf04c40ccc1f4afe203c8dc22f559db3", null ],
    [ "plcol0", "classplplot.html#a36709a68bd249d75667545fadfacce56", null ],
    [ "plcol1", "classplplot.html#a80d9e51c207e539752c5c6a3e190d0e9", null ],
    [ "PLColor", "classplplot.html#ad775c203b72279b0eea580058f769227", null ],
    [ "plconfigtime", "classplplot.html#a8f20a70ffb4bd540604f03162a2e6c2b", null ],
    [ "plcontf", "classplplot.html#a947d6130c7bab75db0de9a942dbf9737", null ],
    [ "PLControlPt", "classplplot.html#a0630fe0def05bf5565fa3d01a47eb377", null ],
    [ "plcpstrm", "classplplot.html#a5dae076c6e23c9a0d6b1fcf87d1077cf", null ],
    [ "plctime", "classplplot.html#a8bebeb7b4242f3ce6c6942cc9987c465", null ],
    [ "PLDisplay", "classplplot.html#a348066e61ef5851261cbff823248aaaa", null ],
    [ "plend", "classplplot.html#a206a3acff23238c0da8009b7a6d26352", null ],
    [ "plend1", "classplplot.html#af0def8ece24e4606f9b58ae67438a61e", null ],
    [ "plenv", "classplplot.html#a661a84dd8e8131c127dbbe63aedee622", null ],
    [ "plenv0", "classplplot.html#a8f1909ae19cdaaf7e589ad93098c6c0b", null ],
    [ "pleop", "classplplot.html#aadd0938b4b4299dbef38ed97213c44dc", null ],
    [ "PLESC_ALLOC_NCOL", "classplplot.html#a2979bf621b0b9dee428474471c7b4b03", null ],
    [ "PLESC_CLEAR", "classplplot.html#a21fee60e87ed0dc7242db6c3d8841d62", null ],
    [ "PLESC_DASH", "classplplot.html#a491c412ec528c6ff3ea856939c335590", null ],
    [ "PLESC_DEV2PLCOL", "classplplot.html#a52cae4e01a1a75f7cb601dd0f7a56b71", null ],
    [ "PLESC_DEVINIT", "classplplot.html#a5903b77b5247beadbb6c1074134d8501", null ],
    [ "PLESC_DI", "classplplot.html#a0299a17812a13b6648e974a76fe820aa", null ],
    [ "PLESC_DOUBLEBUFFERING", "classplplot.html#a7964872238c50644f358d43c9d603a44", null ],
    [ "PLESC_DOUBLEBUFFERING_DISABLE", "classplplot.html#ab1f1ac3baa47a089d514e163c79cacec", null ],
    [ "PLESC_DOUBLEBUFFERING_ENABLE", "classplplot.html#a22554c3a2e252e794f942b497736a0d4", null ],
    [ "PLESC_DOUBLEBUFFERING_QUERY", "classplplot.html#af5317b273220e599a6ebb217b0b75a94", null ],
    [ "PLESC_EH", "classplplot.html#a2521683da2a6317d0522345656c06c30", null ],
    [ "PLESC_EXPOSE", "classplplot.html#a0b1fe72940429950c12cd26be519e84b", null ],
    [ "PLESC_FILL", "classplplot.html#a20c11e1f55c5dc2cab61af574b65bd1c", null ],
    [ "PLESC_FLUSH", "classplplot.html#aae67edbc2f85e1d916a2a1c316669642", null ],
    [ "PLESC_GETC", "classplplot.html#a4faa897aeb746b0025dda6037574571a", null ],
    [ "PLESC_GRAPH", "classplplot.html#a24a4bd3a1038035154a7bc5cbe284cdd", null ],
    [ "PLESC_HAS_TEXT", "classplplot.html#a714a6de0bc30ecca7c16eb3cb57a8705", null ],
    [ "PLESC_IMAGE", "classplplot.html#aa2d5257121ceac78b398591611f6922a", null ],
    [ "PLESC_IMAGEOPS", "classplplot.html#a7bcdb534a1c7498b4eebb9f8c541e682", null ],
    [ "PLESC_PL2DEVCOL", "classplplot.html#a80b4ad54c29d219f548b0c88dade18f7", null ],
    [ "PLESC_REDRAW", "classplplot.html#a1d45738370d6c2a7cc794a4b1b48dab9", null ],
    [ "PLESC_RESIZE", "classplplot.html#ad249b2d955c8df2745f15a5db04ccb31", null ],
    [ "PLESC_SET_COMPRESSION", "classplplot.html#a8bcdaf79b5bbabc4802d69b8174889b8", null ],
    [ "PLESC_SET_LPB", "classplplot.html#a61b181837bb486ec54cebf15d7cd4d30", null ],
    [ "PLESC_SET_RGB", "classplplot.html#a861f741ff4f852792232de58c3eca85c", null ],
    [ "PLESC_SETBGFG", "classplplot.html#ab62905aeae38f8946f9141b4bbc39aef", null ],
    [ "PLESC_SWIN", "classplplot.html#a1eee1c2b673f7f1a6fa8f2e6cf02602c", null ],
    [ "PLESC_TEXT", "classplplot.html#a212ee183d577400d542ec74a78268b7d", null ],
    [ "PLESC_XORMOD", "classplplot.html#ab0f6257cc1022a78aaaf66dc551407cf", null ],
    [ "plfamadv", "classplplot.html#accb5fc9efe774fac0c27ade42896fa3c", null ],
    [ "PLfGrid", "classplplot.html#a8ad11f18fef6acd1ac3d69c59d681ea2", null ],
    [ "PLfGrid2", "classplplot.html#a375e738f3a47becf6b450e4d4095f13a", null ],
    [ "plflt", "classplplot.html#af4efe2eb24aa2b34e81343c5e44c8fb2", null ],
    [ "plflush", "classplplot.html#a1bd7e4bce7e66986a3bfd8020a00d400", null ],
    [ "plfont", "classplplot.html#a143cde9cd53a8fc88bd715d6874078a0", null ],
    [ "plfontld", "classplplot.html#a3ac96186aa875aa8f8b4018d8857ec97", null ],
    [ "plgchr", "classplplot.html#a4740b3152e693a88adf05a2d8fb9cc4c", null ],
    [ "plgcol0", "classplplot.html#aee668e1f682f284f35de10956712d74e", null ],
    [ "plgcol0a", "classplplot.html#aba4d56cf40db646dd70d9ae6cff8bbff", null ],
    [ "plgcolbg", "classplplot.html#a4ef5f7d59ba4c288d908e76163d3ccdc", null ],
    [ "plgcolbga", "classplplot.html#a5f62e9b006b26ef96ecc6cf7e77531cd", null ],
    [ "plgcompression", "classplplot.html#a7a81cf632ae9df7cae6c203bbef62630", null ],
    [ "plgdidev", "classplplot.html#a617604d51d9a80b6686b8308fb3e1c36", null ],
    [ "plgdiori", "classplplot.html#af961ef5da21a81b18d171376ef94b18c", null ],
    [ "plgdiplt", "classplplot.html#abc008579d8fd86bc0c05cc70dc58d9e3", null ],
    [ "plgfam", "classplplot.html#a5fbcfdcebba08a24c6ddb3d6833e0b20", null ],
    [ "plgfci", "classplplot.html#aa8049d9d7507ac6898e1a7aa7c1a7a7a", null ],
    [ "plgfont", "classplplot.html#a49f622e5ecebe8a8a8c533ef7b7147cc", null ],
    [ "plglevel", "classplplot.html#a684a40de7df9b1245ba65418a934acb5", null ],
    [ "plgpage", "classplplot.html#a3ea029481312eba078267195c00ac49f", null ],
    [ "plgra", "classplplot.html#af845cb9c21709d1a909f35ac7583b5e6", null ],
    [ "PLGraphicsIn", "classplplot.html#a82e8dbdc52db5d91f5281bfb8c8b0431", null ],
    [ "plgrdient", "classplplot.html#a6b1b01c91352e4604dee86e9832dab15", null ],
    [ "plgspa", "classplplot.html#a960542b47254ac706233952c17f631c8", null ],
    [ "plgstrm", "classplplot.html#a319347f5d960600163067fe46d18f835", null ],
    [ "plgvpd", "classplplot.html#afeb410421b90295cca78c029641bc1fa", null ],
    [ "plgvpw", "classplplot.html#ab41fb913fe8ae19776f497b9617d82b1", null ],
    [ "plgxax", "classplplot.html#a085debd0f0bde29e49fec966f523785b", null ],
    [ "plgyax", "classplplot.html#a4f3a12892973912d5a8dee3e1e8a295e", null ],
    [ "plgzax", "classplplot.html#af5c0e84849a4d583319c8ba9ea4f624e", null ],
    [ "plhls", "classplplot.html#af689fe17bd5301e7eeadb81df9d63701", null ],
    [ "plhlsrgb", "classplplot.html#af11e32a0abb90a268917a3d52bc5d252", null ],
    [ "plinit", "classplplot.html#a2d79ac193881aa0e5afd2b9dca8e86cb", null ],
    [ "PLINT", "classplplot.html#a31de7bf1fe7bbee8db21098bae902b7b", null ],
    [ "pljoin", "classplplot.html#a3d0a024fee80c4a608278401f2f0844e", null ],
    [ "pllightsource", "classplplot.html#aea54e9a8e2238a4cbe1de332d285f817", null ],
    [ "pllsty", "classplplot.html#ae50b8882b845df12f536c8e10f33025c", null ],
    [ "plmeridians", "classplplot.html#a836b948926218fb942b7b68b1d8fe985", null ],
    [ "plmkstrm", "classplplot.html#ad4729e332c9db6847a940c4a5352c154", null ],
    [ "PLOptionTable", "classplplot.html#adad93e76e186a31ff7d640cb6fcb3929", null ],
    [ "plP_gvpd", "classplplot.html#ab3e0f6270d0e196edd9e955c6bd3be45", null ],
    [ "plP_gvpw", "classplplot.html#a786fc5cb91f37bec488f2ff914e12032", null ],
    [ "plpage", "classplplot.html#a8d1e19a3d2b1302dce0fc6d6e1031ccf", null ],
    [ "plpath", "classplplot.html#a9a74b0d5ef9492e9552f32f0edd23f07", null ],
    [ "PLPointer", "classplplot.html#ab4c487625f5fe57d3596a974a4ac01e8", null ],
    [ "plprec", "classplplot.html#a53419da11726b76f962f76474579d482", null ],
    [ "plpsty", "classplplot.html#a85a8e7a9fe415d6d467fed88ac7425fa", null ],
    [ "plrandd", "classplplot.html#a25aab7f205ac187d6d68ee3a930f98e6", null ],
    [ "plreplot", "classplplot.html#a06dbd3cd8ad2c0390a254e1ee9a1cf72", null ],
    [ "plrgb", "classplplot.html#af04d711c7bb1bc2517cce2d11f1cf814", null ],
    [ "plrgb1", "classplplot.html#a405247d752782554a6cdff5990f37abf", null ],
    [ "plrgbhls", "classplplot.html#ab4238ee20a5f2e96ceeb37735c5dfc0b", null ],
    [ "plschr", "classplplot.html#ad6cd0529533f2cc181419ca7074542d1", null ],
    [ "plscmap0n", "classplplot.html#ab9a5f82e8597b07980b6b82567ad1142", null ],
    [ "plscmap1_range", "classplplot.html#ab9c238eaf06c3f112b133a27c18bbc0a", null ],
    [ "plscmap1n", "classplplot.html#acb861d5300a5c6ac3933bd7729fc05f5", null ],
    [ "plscol0", "classplplot.html#ab9680ca15d97e394b220a3f2f18f4b57", null ],
    [ "plscol0a", "classplplot.html#ad47805ae72e397df030b927da8910188", null ],
    [ "plscolbg", "classplplot.html#a72f5ce4b770385225aad8c0b76efa39c", null ],
    [ "plscolbga", "classplplot.html#af7f482f30c637a9ba44df1252a314ebd", null ],
    [ "plscolor", "classplplot.html#ae3f5358ddd16cd7da58a9fa66dc47bed", null ],
    [ "plscompression", "classplplot.html#afe9412a621fba4de36072b41ebe5d846", null ],
    [ "plsdidev", "classplplot.html#a6516d20a9b431a865bd2c9441b7d584b", null ],
    [ "plsdimap", "classplplot.html#a76329f12d4bcadbdbc283e0b7d6bc940", null ],
    [ "plsdiori", "classplplot.html#a637dd2d2ad4325426efa3b61df84d544", null ],
    [ "plsdiplt", "classplplot.html#ab3c67aadedee13ab0df9377dce043efc", null ],
    [ "plsdiplz", "classplplot.html#a7675975e9ecb0a6a00126ec284bb9ace", null ],
    [ "plseed", "classplplot.html#a09494b7075775c8444a1763089e0416c", null ],
    [ "plsesc", "classplplot.html#ac637bc0b6cd60b2675192b3028679649", null ],
    [ "plsfam", "classplplot.html#adc832b0c8c0fa6548fa98bee741f0bf1", null ],
    [ "plsfci", "classplplot.html#a2a902e5d8a9f551d9da2e6af704da9ed", null ],
    [ "plsfont", "classplplot.html#ae5cc0e6c15cd5964b0233a691e27c8fd", null ],
    [ "plslabelfunc", "classplplot.html#a478fbbc530aa2127e1a530a569968ecc", null ],
    [ "plsmaj", "classplplot.html#aa1086fbb8f3a73083b205f14783c9c11", null ],
    [ "plsmem", "classplplot.html#a707227bacf7694b6ab3161ea9ce6e1d2", null ],
    [ "plsmin", "classplplot.html#a1603215a3b917adc7b4ab0b790867344", null ],
    [ "plsori", "classplplot.html#afd09c57f50f8004fb766f24388b9d0b7", null ],
    [ "plspage", "classplplot.html#a066171bf8dd4a36cd74e6eac59bf609d", null ],
    [ "plspause", "classplplot.html#a5031282d76c363257ee14bec3c132038", null ],
    [ "plsstrm", "classplplot.html#ae257e5409828a91e9ef7d4117b738fe0", null ],
    [ "plssub", "classplplot.html#a06994b5bad5a5fcbbd870073a8b17fdf", null ],
    [ "plssym", "classplplot.html#a547da7c62d0e52733af100eebf25b7ba", null ],
    [ "plstar", "classplplot.html#ae8357a44ea95b90fb8c8d8043e381806", null ],
    [ "plstransform", "classplplot.html#a7630fb082e626b8fdcc23fdb260b66f5", null ],
    [ "plstripa", "classplplot.html#aa92f13bd259d65d50bf775a72eff0a91", null ],
    [ "plstripd", "classplplot.html#aac3e6742466acd0bebc51af04dd08e13", null ],
    [ "plsvpa", "classplplot.html#ac81b9e82d78b1afa029336f30042db38", null ],
    [ "PLSWIN_DEVICE", "classplplot.html#a23e11e97f2e5237fc18c6d0026ddfbf9", null ],
    [ "PLSWIN_WORLD", "classplplot.html#aee9ccfe5fe54a3f7831598f159eadbcd", null ],
    [ "plsxax", "classplplot.html#adaf430d0e3383ed209149a1a8059c3c2", null ],
    [ "plsyax", "classplplot.html#a3440233c89f0188596a7f773b0f4ebf3", null ],
    [ "plszax", "classplplot.html#a489016ad9024f3613f14a5474f915efb", null ],
    [ "pltext", "classplplot.html#a250d95fcf548bc4dd658d3ddc02c8f37", null ],
    [ "PLUNICODE", "classplplot.html#ae6821277959dc78b2623efa4c6293b12", null ],
    [ "plvasp", "classplplot.html#a6d01a94c0ac3f7e1fa7e72eabad1179b", null ],
    [ "plvpas", "classplplot.html#acda6f8cf1dd36564c294fcc170b557d3", null ],
    [ "plvpor", "classplplot.html#a337563b49b342e18ea2c372c38ae9962", null ],
    [ "plvsta", "classplplot.html#ae0d90e76073ffa70669e95f60d4f8b4b", null ],
    [ "plw3d", "classplplot.html#a7b7e981d7224c5c72cf27741314a1a48", null ],
    [ "plwidth", "classplplot.html#a8d35de2ce79d7bfec3f744b36617a1a7", null ],
    [ "plwind", "classplplot.html#afa1fbb244390844aaf38c6ef7e63ff2a", null ],
    [ "PLWindow", "classplplot.html#adceee7930422cfa970f42901b6b64346", null ],
    [ "plxormod", "classplplot.html#ae78f5f7d2f17258acdd9d17dc2daafe8", null ],
    [ "SURF_CONT", "classplplot.html#a3dbcd533882c885f8bdb735f0f014d29", null ],
    [ "TOP_CONT", "classplplot.html#a6cfeabea1528ccf4bd2bd5ab8fed39bd", null ],
    [ "ZEROW2B", "classplplot.html#a5d997425805067f835283aacfa10b6c8", null ],
    [ "ZEROW2D", "classplplot.html#a1d915ee217645fec17703357052c855a", null ]
];